Enum acrylic::core::visual::LayoutMode
source · pub enum LayoutMode {
Unset,
WrapContent,
Fixed(Pixels),
Chunks(Pixels),
AspectRatio(Ratio),
Remaining(Ratio),
}Expand description
Possible ways for a node to be positioned
Variants
Unset
Node will be ignored by the layout algorithm
WrapContent
Main length is just enough to contain all children. Valid for containers only.
Fixed(Pixels)
Main length is a fixed number of pixels.
Chunks(Pixels)
Main length is divided in chunks of specified length (in pixels). The number of chunks is determined by the contained nodes: there will be as many chunks as necessary for all children to fit in. For this to work, the node must be:
- A vertical container in an vorizontal container, or
- An horizontal container in a vertical container.
AspectRatio(Ratio)
Main length is computed from the cross length so that the size of the node maintains a certain aspect ratio.
Remaining(Ratio)
After neighbors with a different policy are layed
out, nodes with this policy are layed-out so that
they occupy the remaining space in their container.
The Ratio is the relative “weight” of this node:
heavier nodes will get more space, lighter nodes
will get less space. If they all have the same
weight, they will all get the same space.